<template>
  <a-spin :spinning='confirmLoading'>
    <j-form-container :disabled='formDisabled'>
      <a-form-model ref='form' :model='model' :rules='validatorRules' slot='detail'>
        <a-row>
          <a-col :span='24'>
            <a-form-model-item label='编码' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='code'>
              <a-input v-model='model.code' placeholder='请输入编码'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='名称' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='name'>
              <a-input v-model='model.name' placeholder='请输入名称'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='版本' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='ver'>
              <a-input v-model='model.ver' placeholder='请输入版本'></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span='24'>
            <a-form-model-item label='启用状态' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='enabled'>
              <j-switch v-model='model.enabled'></j-switch>
            </a-form-model-item>
          </a-col>

          <a-col :lg='24'>
            <a-form-model-item label='状态' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='status'>
              <j-dict-select-tag v-model='model.status' title='状态' dictCode='outline_status'  disabled placeholder='请选择鉴定大纲状态' />
            </a-form-model-item>
          </a-col>

          <a-col :span='24'>
            <a-form-model-item label='备注' :labelCol='labelCol' :wrapperCol='wrapperCol' prop='remark'>
              <a-input v-model='model.remark' placeholder='请输入备注'></a-input>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </j-form-container>
  </a-spin>
</template>

<script>

import { httpAction, getAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'

export default {
  name: 'LimsTestingOutlineForm',
  components: {},
  props: {
    //表单禁用
    disabled: {
      type: Boolean,
      default: false,
      required: false
    }
  },
  data() {
    return {
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      validatorRules: {
        code: [{ required: true, message: '鉴定大纲编号不能为空', trigger: 'blur' }],
        name: [{ required: true, message: '鉴定大纲名称不能为空', trigger: 'blur' }],
        ver: [{ required: true, message: '鉴定大纲版本不能为空', trigger: 'blur' }],
        status: [{ required: true, message: '鉴定大纲状态不能为空', trigger: 'blur' }],
        enabled: [{ required: true, message: '鉴定大纲使用状态不能为空', trigger: 'blur' }]
      },
      url: {
        add: '/lims/testing/outline/add',
        edit: '/lims/testing/outline/edit',
        queryById: '/lims/testing/outline/queryById'
      }
    }
  },
  computed: {
    formDisabled() {
      return this.disabled
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model))
  },
  methods: {
    add() {
      //设置状态为新建
      this.modelDefault.status = 0
      this.modelDefault.enabled = 1
      this.edit(this.modelDefault)
    },
    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },
    submitForm() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            httpurl += this.url.edit
            method = 'put'
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        }

      })
    }
  }
}
</script>